==> qt5-tools-debuginfo-5.9.2-1.tar.xz: usr/src/debug/qt5-tools-5.9.2-1/src/designer/src/plugins/qquickwidget/.rcc/qrc_qquickwidget_plugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.2-1.x86_64/src/qttools-opensource-src-5.9.2/src/designer/src/plugins/qquickwidget/images/qquickwidget.png
  0x0,0x0,0x2,0x48,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x3,0x0,0x0,0x0,0xf3,0x6a,0x9c,0x9,
  0x0,0x0,0x1,0x1d,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0xff,0xff,0xff,0x4d,0x4d,
  0x4d,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x7d,0x7d,0x7d,0x6f,0x6f,0x6f,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0xd8,0xd8,0xd8,0x8d,0x8d,0x8d,0xb6,0xb6,0xb6,0xa5,0xa5,0xa5,0xdf,
  0xdf,0xdf,0xb5,0xb5,0xb5,0xb2,0xb2,0xb2,0xd3,0xd3,0xd3,0xce,0xce,0xce,0xd2,0xd2,
  0xd2,0xc7,0xc7,0xc7,0xd0,0xd0,0xd0,0xda,0xda,0xda,0xbd,0xbd,0xbd,0xbb,0xbb,0xbb,
  0xe2,0xe2,0xe2,0xb1,0xb1,0xb1,0xcc,0xcc,0xcc,0x80,0x80,0x80,0x94,0x94,0x94,0xc8,
  0xc8,0xc8,0xc2,0xc2,0xc2,0xaf,0xaf,0xaf,0x92,0x92,0x92,0xd4,0xd4,0xd4,0xd7,0xd7,
  0xd7,0xd1,0xd1,0xd1,0xa7,0xa7,0xa7,0xb7,0xb7,0xb7,0xd6,0xd6,0xd6,0x87,0x87,0x87,
  0xa8,0xa8,0xa8,0x9e,0x9e,0x9e,0xb3,0xb3,0xb3,0xcd,0xcd,0xcd,0xb9,0xb9,0xb9,0x93,
  0x93,0x93,0xc3,0xc3,0xc3,0x8c,0x8c,0x8c,0x90,0x90,0x90,0xa3,0xa3,0xa3,0xa4,0xa4,
  0xa4,0xa0,0xa0,0xa0,0x9a,0x9a,0x9a,0xad,0xad,0xad,0xbf,0xbf,0xbf,0xaa,0xaa,0xaa,
  0x79,0x79,0x79,0xd9,0xd9,0xd9,0xcf,0xcf,0xcf,0xac,0xac,0xac,0xe0,0xe0,0xe0,0xdc,
  0xdc,0xdc,0xc4,0xc4,0xc4,0x15,0x21,0x2b,0x4e,0x0,0x0,0x0,0x29,0x74,0x52,0x4e,
  0x53,0x0,0x0,0x0,0xc3,0x2d,0xd2,0xe1,0xd8,0x6c,0x18,0x84,0xf6,0xc,0x93,0xdb,
  0x27,0x48,0x9,0x12,0xa5,0x3,0x7b,0x57,0xea,0xcf,0xcc,0x33,0x8d,0xfc,0x3c,0x15,
  0xf9,0xc5,0xc6,0x63,0x36,0x87,0xe4,0xe7,0x4b,0xb7,0xc,0x3d,0x49,0x31,0x0,0x0,
  0x0,0xb1,0x49,0x44,0x41,0x54,0x18,0xd3,0x63,0x60,0xa0,0x12,0x60,0x44,0x3,0xd8,
  0x85,0x39,0x51,0x84,0x99,0xa0,0x80,0x83,0xf,0x8b,0x30,0x3f,0x73,0x34,0x3b,0x86,
  0xb0,0x88,0x28,0xb7,0xb9,0x33,0x2b,0xba,0x30,0x8b,0x44,0xb8,0xa9,0x9b,0x1,0x9a,
  0xb0,0x20,0x97,0x8c,0xab,0xae,0xa9,0x89,0x15,0x33,0x8a,0xb0,0x2c,0xbb,0x8b,0x51,
  0x64,0x8c,0x8f,0x85,0x1f,0xb2,0x30,0xf,0xaf,0xaf,0x9e,0x91,0x81,0xae,0x76,0x94,
  0x69,0x18,0x92,0xb0,0x0,0x5b,0xa0,0x95,0xb7,0x61,0x6c,0x5c,0xa8,0x85,0xa1,0x39,
  0x5c,0x58,0x48,0xd8,0xc6,0xd2,0xd8,0xd8,0x56,0xd3,0x30,0xc4,0x48,0xd3,0x58,0x1b,
  0x26,0x2c,0x26,0x6e,0x6d,0xed,0xaf,0x15,0x64,0x62,0x12,0x6c,0xa9,0x6b,0x6b,0xa7,
  0x27,0x89,0x64,0x36,0x8b,0x94,0xb4,0x8e,0xbd,0x83,0xa3,0x93,0x99,0x99,0x3e,0xaa,
  0x3,0xe5,0xe4,0xdd,0x3d,0x74,0xb4,0x3c,0xbd,0xf4,0xd9,0x50,0xdd,0xad,0x10,0xa1,
  0xa8,0xa4,0xac,0xa2,0x1a,0xa0,0x86,0x2a,0xcc,0xc2,0x2,0xe,0x15,0x75,0xd,0x6a,
  0x45,0x18,0x0,0xe9,0xd7,0x17,0x5b,0x64,0x21,0x78,0xfb,0x0,0x0,0x0,0x0,0x49,
  0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // qquickwidget
  0x0,0xc,
  0xd,0xce,0xd2,0x84,
  0x0,0x71,
  0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x77,0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,
    // images
  0x0,0x6,
  0x7,0x3,0x7d,0xc3,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x73,
    // qquickwidget.png
  0x0,0x10,
  0x2,0x9c,0xca,0xe7,
  0x0,0x71,
  0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x77,0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/qquickwidget
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/qquickwidget/images
  0x0,0x0,0x0,0x40,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/qquickwidget/images/qquickwidget.png
  0x0,0x0,0x0,0x52,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0xc7,0xb5,0xc8,0xc8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qquickwidget_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qquickwidget_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qquickwidget_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qquickwidget_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qquickwidget_plugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qquickwidget_plugin)(); }
   } dummy;
}

==> qt5-tools-debuginfo-5.9.3-1.tar.xz: usr/src/debug/qt5-tools-5.9.3-1/src/designer/src/plugins/qquickwidget/.rcc/qrc_qquickwidget_plugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.3-1.i686/src/qttools-opensource-src-5.9.3/src/designer/src/plugins/qquickwidget/images/qquickwidget.png
  0x0,0x0,0x2,0x48,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x3,0x0,0x0,0x0,0xf3,0x6a,0x9c,0x9,
  0x0,0x0,0x1,0x1d,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0xff,0xff,0xff,0x4d,0x4d,
  0x4d,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x7d,0x7d,0x7d,0x6f,0x6f,0x6f,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,
  0x80,0x80,0x80,0xd8,0xd8,0xd8,0x8d,0x8d,0x8d,0xb6,0xb6,0xb6,0xa5,0xa5,0xa5,0xdf,
  0xdf,0xdf,0xb5,0xb5,0xb5,0xb2,0xb2,0xb2,0xd3,0xd3,0xd3,0xce,0xce,0xce,0xd2,0xd2,
  0xd2,0xc7,0xc7,0xc7,0xd0,0xd0,0xd0,0xda,0xda,0xda,0xbd,0xbd,0xbd,0xbb,0xbb,0xbb,
  0xe2,0xe2,0xe2,0xb1,0xb1,0xb1,0xcc,0xcc,0xcc,0x80,0x80,0x80,0x94,0x94,0x94,0xc8,
  0xc8,0xc8,0xc2,0xc2,0xc2,0xaf,0xaf,0xaf,0x92,0x92,0x92,0xd4,0xd4,0xd4,0xd7,0xd7,
  0xd7,0xd1,0xd1,0xd1,0xa7,0xa7,0xa7,0xb7,0xb7,0xb7,0xd6,0xd6,0xd6,0x87,0x87,0x87,
  0xa8,0xa8,0xa8,0x9e,0x9e,0x9e,0xb3,0xb3,0xb3,0xcd,0xcd,0xcd,0xb9,0xb9,0xb9,0x93,
  0x93,0x93,0xc3,0xc3,0xc3,0x8c,0x8c,0x8c,0x90,0x90,0x90,0xa3,0xa3,0xa3,0xa4,0xa4,
  0xa4,0xa0,0xa0,0xa0,0x9a,0x9a,0x9a,0xad,0xad,0xad,0xbf,0xbf,0xbf,0xaa,0xaa,0xaa,
  0x79,0x79,0x79,0xd9,0xd9,0xd9,0xcf,0xcf,0xcf,0xac,0xac,0xac,0xe0,0xe0,0xe0,0xdc,
  0xdc,0xdc,0xc4,0xc4,0xc4,0x15,0x21,0x2b,0x4e,0x0,0x0,0x0,0x29,0x74,0x52,0x4e,
  0x53,0x0,0x0,0x0,0xc3,0x2d,0xd2,0xe1,0xd8,0x6c,0x18,0x84,0xf6,0xc,0x93,0xdb,
  0x27,0x48,0x9,0x12,0xa5,0x3,0x7b,0x57,0xea,0xcf,0xcc,0x33,0x8d,0xfc,0x3c,0x15,
  0xf9,0xc5,0xc6,0x63,0x36,0x87,0xe4,0xe7,0x4b,0xb7,0xc,0x3d,0x49,0x31,0x0,0x0,
  0x0,0xb1,0x49,0x44,0x41,0x54,0x18,0xd3,0x63,0x60,0xa0,0x12,0x60,0x44,0x3,0xd8,
  0x85,0x39,0x51,0x84,0x99,0xa0,0x80,0x83,0xf,0x8b,0x30,0x3f,0x73,0x34,0x3b,0x86,
  0xb0,0x88,0x28,0xb7,0xb9,0x33,0x2b,0xba,0x30,0x8b,0x44,0xb8,0xa9,0x9b,0x1,0x9a,
  0xb0,0x20,0x97,0x8c,0xab,0xae,0xa9,0x89,0x15,0x33,0x8a,0xb0,0x2c,0xbb,0x8b,0x51,
  0x64,0x8c,0x8f,0x85,0x1f,0xb2,0x30,0xf,0xaf,0xaf,0x9e,0x91,0x81,0xae,0x76,0x94,
  0x69,0x18,0x92,0xb0,0x0,0x5b,0xa0,0x95,0xb7,0x61,0x6c,0x5c,0xa8,0x85,0xa1,0x39,
  0x5c,0x58,0x48,0xd8,0xc6,0xd2,0xd8,0xd8,0x56,0xd3,0x30,0xc4,0x48,0xd3,0x58,0x1b,
  0x26,0x2c,0x26,0x6e,0x6d,0xed,0xaf,0x15,0x64,0x62,0x12,0x6c,0xa9,0x6b,0x6b,0xa7,
  0x27,0x89,0x64,0x36,0x8b,0x94,0xb4,0x8e,0xbd,0x83,0xa3,0x93,0x99,0x99,0x3e,0xaa,
  0x3,0xe5,0xe4,0xdd,0x3d,0x74,0xb4,0x3c,0xbd,0xf4,0xd9,0x50,0xdd,0xad,0x10,0xa1,
  0xa8,0xa4,0xac,0xa2,0x1a,0xa0,0x86,0x2a,0xcc,0xc2,0x2,0xe,0x15,0x75,0xd,0x6a,
  0x45,0x18,0x0,0xe9,0xd7,0x17,0x5b,0x64,0x21,0x78,0xfb,0x0,0x0,0x0,0x0,0x49,
  0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // qquickwidget
  0x0,0xc,
  0xd,0xce,0xd2,0x84,
  0x0,0x71,
  0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x77,0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,
    // images
  0x0,0x6,
  0x7,0x3,0x7d,0xc3,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x73,
    // qquickwidget.png
  0x0,0x10,
  0x2,0x9c,0xca,0xe7,
  0x0,0x71,
  0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x77,0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/qquickwidget
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/qquickwidget/images
  0x0,0x0,0x0,0x40,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/qquickwidget/images/qquickwidget.png
  0x0,0x0,0x0,0x52,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x9a,0xa1,0x2d,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qquickwidget_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qquickwidget_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qquickwidget_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qquickwidget_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qquickwidget_plugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qquickwidget_plugin)(); }
   } dummy;
}
